@@ -5,7 +5,8 @@ library(party)
 gctorture(on = GCtorture)
 
 ### get rid of the NAMESPACE
-load(file.path(.find.package("party"), "R", "all.rda"))
+nsparty <- attach(NULL, name="ns-party")
+.Internal(lib.fixup(asNamespace("party"), nsparty))
 
 ### 
 ###
